<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>O programie </translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Wspomóż</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licencja: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Zrzut ekranu i narzędzie adnotacji</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Skrót</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Przechwyć</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Uwzględnij kursor</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Opóźnij</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Tryb przechwytywania</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Pokaż obraz w oknie Pin</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Kopiuj obraz do schowka</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Prześlij obraz</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Otwórz nadrzędny katalog obrazu</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Zapisz obraz</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Ukryj główne okno</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Ustawienia działań</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Działanie</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Wymagany obraz znaku wodnego</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Dodaj obraz znaku wodnego, wybierając Opcje &gt; Ustawienia &gt; Komentarz &gt; Aktualizuj</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Wygładzaj linie rysunkowe</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Po włączeniu wygładza linie pióra i
ścieżki znaczników po zakończeniu rysowania.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Współczynnik wygładzania</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Zwiększenie współczynnika wygładzania spowoduje
zmniejszenie dokładności pióra i markera
ale uczyni je bardziej gładkimi.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Ustawienia komentarza</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Zapamiętaj wybór narzędzia do adnotacji i załaduj go podczas uruchamiania</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Przejdź do opcji Wybierz narzędzie po narysowaniu elementu</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Narzędzie numeracji Zmiana numeru aktualizuje wszystkie ponumerowane pozycje</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Wyłączenie tej opcji powoduje zmiany narzędzia numeracji.
Dotyczy tylko nowych elementów i nie wpływa na już istniejące elementy.
Wyłączenie tej opcji spowoduje zduplikowanie numerów.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Kolor płótna</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Domyślny kolor tła obszaru roboczego dla obszaru adnotacji.
Zmiana koloru wpływa tylko na nowe obszary adnotacji.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Wybierz element po narysowaniu</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Po włączeniu tej opcji element jest zaznaczany po
utworzeniu, co pozwala na zmianę ustawień.</translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Przechwytuj zrzut ekranu przy uruchamianiu w trybie domyślnym</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Styl aplikacji</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Ustawia styl aplikacji, który definiuje wygląd i działanie interfejsu GUI.
Zmiana wymaga ponownego uruchomienia ksnip, aby odniosła skutek.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Ustawienia aplikacji</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Automatycznie kopiuj nowe zrzuty do schowka</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Użyj zakładek</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Zmiana wymaga ponownego uruchomienia.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Uruchom ksnip jako pojedynczą instancję</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Ukryj pasek zakładek, gdy używana jest tylko jedna karta.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Włączenie tej opcji pozwoli na uruchomienie tylko jednej instancji ksnip,
wszystkie inne instancje uruchomione po pierwszym przekażą ich
argumenty do pierwszego i zostaną zamknięte. Zmiana tej opcji wymaga
ponownego uruchomienia wszystkich instancji.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Zapamiętaj pozycję okna głównego podczas przenoszenia i ładowania przy starcie</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Ukryj automatycznie Zakładki</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Ukryj automatycznie Doki</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Po uruchomieniu ukryj pasek narzędzi i ustawienia adnotacji.
Widoczność doków można przełączać za pomocą klawisza Tab.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Dostosuj rozmiar do zawartości</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Automatyczna zmiana rozmiaru okna głównego w celu dopasowania do zawartości obrazu.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Włącz debugowanie</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Włącza debugowanie danych wyjściowych zapisanych w konsoli.
Zmiana wymaga ponownego uruchomienia ksnip.</translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation>Zmiana rozmiaru do opóźnienia zawartości</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>Zmiana rozmiaru zawartości jest opóźnione, aby umożliwić menedżerowi okien odebranie
nowej zawartości. W przypadku, gdy główne okno nie jest poprawnie dostosowane
do nowej zawartości, zwiększenie tego opóźnienia może poprawić zachowanie.</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Współtwórcy:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Tłumaczenie na język hiszpański</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Tłumaczenie na język niderlandzki</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Tłumaczenie na język rosyjski</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Tłumaczenie na język norweski Bokmål</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Tłumaczenie na język francuski</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Tłumaczenie na język polski</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Obsługa Snap &amp; Flatpak</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Autorzy:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Ostrzeżenie - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>Zrzut z ekranu %1%2%3 został zmodyfikowany.
Chcesz go zapisać?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Narysuj myszką prostokątny obszar</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Przechwyć pełny ekran, w tym wszystkie monitory</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Przechwyć ekran, na którym znajduje się myszka</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Przechwyć okno, które aktualnie jest aktywne</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Przechwyć okno, które jest aktualnie pod kursorem myszy</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Wykonaj zrzut ekranu z ostatnio wybranym prostokątnym obszarem</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Wykorzystuje portal do robienia zrzutów ekranu</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Społeczność</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Zgłaszanie błędów</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Jeśli masz ogólne pytania, pomysły lub po prostu chcesz porozmawiać o ksnip,&lt;br/&gt;dołącz do naszego serwera %1 lub %2.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Użyj %1, aby zgłosić błędy.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Nieudane kopiowanie do schowka</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Nie udało się skopiować do schowka obrazu zakodowanego w base64.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Skopiowano do schowka</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Skopiowano do schowka jako obraz zakodowany base64.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Usuń Obraz</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Element &apos;%1&apos; zostanie usunięty.
Czy chcesz kontynuować?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Darowizny są zawsze mile widziane</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Wspomóż</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip jest niedochodowym projektem wolnego oprogramowania objętego licencją typu copylefted &lt;br/&gt; i nadal ma pewne koszty, które trzeba pokryć, takie jak koszty domeny lub koszty sprzętu&lt;br/&gt; do obsługi wielu platform.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Jeśli chcesz pomóc lub po prostu chcesz docenić wykonywaną pracę&lt;br/&gt;, częstując programistów piwem lub kawą, możesz to zrobić %1tutaj%2.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>Czy możesz być sponsorem GitHub?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Możliwe również, %1tutaj%2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Dodaj nowe akcje, naciskając przycisk &quot;Dodaj&quot;.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Obszar prostokątny</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Ostatni obszar prostokątny</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Pełny ekran (wszystkie monitory)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Bieżący ekran</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Aktywne okno</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Okno pod kursorem</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Portal zrzutu ekranu</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Wymuś anonimowe wysyłanie.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Adres URL</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Przesyłanie FTP</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Przesyłanie zakończone pomyślnie</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Nie można zapisać tymczasowego obrazu do przesłania.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Nie można uruchomić procesu, sprawdź ścieżkę i uprawnienia.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Proces uległ awarii</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Przekroczono limit czasu procesu.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Błąd odczytu procesu.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Błąd zapisu procesu.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Błąd sieciowy, sprawdź dane wyjściowe konsoli.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Przesyłanie nie powiodło się</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Skrypt wysłany do StdErr.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>Przesyłanie FTP zakończyło się pomyślnie.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Nieznany błąd.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Błąd połączenia.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Błąd uprawnień.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>Przesyłanie skryptu %1 zakończone pomyślnie.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>Przesłano do %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Włącz globalne klawisze skrótu</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Przechwyć obszar prostokątny</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Przechwyć pełny ekran</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Przechwyć bieżący ekran</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Przechwyć aktywne okno</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Przechwyć okno pod kursorem</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Globalne skróty klawiszowe</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Przechwyć ostatni obszar prostokątny</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Przechwyć za pomocą Portalu</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>Skróty klawiszowe są obecnie obsługiwane tylko dla systemów Windows i X11.
Wyłączenie tej opcji spowoduje, że skróty akcji będą obsługiwane tylko przez ksnip.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Przechwyć kursor myszy na zrzucie ekranu</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Czy kursor myszy powinien być widoczny
na zrzutach ekranu.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Przechwyć obraz</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Rodzajowe wdrożenia Wayland, które używają
XDG-DESKTOP-PORTAL obsługują skalowanie ekranu
w inny sposób. Włączenie tej opcji określi 
bieżące skalowanie ekranu i 
zastosuje je do zrzutu ekranu w ksnip.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME i KDE Plasma obsługują własny Wayland
oraz zrzuty ekranu Generic XDG-DESKTOP-PORTAL.
Włączenie tej opcji wymusi KDE Plasma
i GNOME do korzystania ze zrzutów ekranu XDG-DESKTOP-PORTAL.
Zmiana tej opcji wymaga ponownego uruchomienia ksnip.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Pokaż okno główne po przechwyceniu zrzutu ekranu</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Ukryj okno główne podczas zrzutu ekranu</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Ukryj okno główne podczas przechwytywania nowego zrzutu ekranu.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Pokaż okno główne po zrobieniu nowego zrzutu ekranu
kiedy główne okno było ukryte lub zminimalizowane.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation type="unfinished">Zrzut ekranu Force Generic Wayland (xdg-desktop-portal)</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Skaluj ogólne zrzuty ekranu Wayland (xdg-desktop-portal)</translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Historia Imgur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Czas</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Usuń link</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Przesyłanie do imgur.com zakończone!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Otrzymano nowy token, próbuję przesłać ponownie…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Token Imgur wygasł, żądanie nowego tokena…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Wymuś anonimowe przesyłanie</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Zawsze kopiuj link Imgur do schowka</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Identyfikator klienta</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Szyfrowanie klienta</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Wpisz Pin imgur, który zostanie wymieniony na token.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Uzyskaj PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Uzyskaj Token</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Historia Imgur</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Prześlij do Imgur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Czekam na imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Token Imgur.com został pomyślnie zaktualizowany.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Błąd aktualizacji tokena Imgur.com.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Po załadowaniu otwórz link Imgur w domyślnej przeglądarce</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Link bezpośrednio do obrazu</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Podstawowy adres URL:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Podstawowy adres URL, który będzie używany do komunikacji z Imgur.
Zmiana wymaga ponownego uruchomienia.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Wyczyść token</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Nie można otworzyć obrazu</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Nie można otworzyć obrazu ze ścieżki %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Opóźnienie w sekundach pomiędzy wywołaniem
i wykonaniem zrzutu ekranu.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Zapisz zrzut ekranu w systemie plików</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Skopiuj zrzut ekranu do schowka</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Narzędzia</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Kadruj</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Kadruj zrzut ekranu</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Niezapisane</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Otwiera okno dialogowe drukarki i umożliwia drukowanie obrazu</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Podgląd wydruku</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Otwiera okno dialogowe Podglądu wydruku, w którym można zmienić orientację obrazu</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skaluj</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programie</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edytuj</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opcje</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Dodaj znak wodny</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Dodaj znak wodny do przechwyconego obrazu. Można dodać wiele znaków wodnych.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Nie można wyświetlić obrazu</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Zapisz jako...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Wklej Osadź</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Pin</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Przypnij zrzut ekranu do pierwszego planu w oknie bez ramek</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Nie dostarczono żadnego obrazu, ale oczekiwano jednego.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopiuj ścieżkę</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Otwórz katalog</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Otwórz obraz</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Pokaż Doki</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Ukryj Doki</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Kopiuj jako dane URI</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Ostatnio &amp;Otwierane</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Modyfikacja płótna</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>Prześlij trigerCapture do zewnętrznego źródła</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Kopiuj triggerCapture do schowka systemowego</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Skaluj obraz</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Obróć</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Obróć obraz</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Działania</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Pliki obrazów</translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Zapisz jako</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Otwórz katalog</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopiuj ścieżkę</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Zrzut z ekranu</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Zamknij inne</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zamknij wszystko</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>Przypnij okno %1</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Zmieniono nazwę obrazu</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Zmiana nazwy obrazu nie powiodła się</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Zmień nazwę obrazu</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Nowa nazwa pliku:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>Pomyślnie zmieniono nazwę obrazu na %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>Nie można zmienić nazwy obrazu na %1</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Zapisz jako</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Wszystkie Pliki</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Obraz został zapisany</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Zapisywanie obrazu nie powiodło się</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Pliki obrazów</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Zapisano w %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>Nie udało się zapisać obrazu w %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Zapisz automatycznie nowe zrzuty w domyślnej lokalizacji</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Pytaj czy zapisać przed odrzuceniem niezapisanych zmian</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Zapamiętaj ostatni katalog zapisywania</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Po włączeniu tej opcji nadpisze zapisany w ustawieniach katalog
najnowszym katalogiem zapisu, dla każdego zapisu.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Lokalizacja zapisu i nazwa pliku</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Obsługiwane formaty to JPG, PNG i BMP. Jeśli format nie zostanie podany, domyślnie zostanie użyty format PNG.
Nazwa pliku może zawierać następujące symbole wieloznaczne:
- $Y, $M, $D dla daty, $h, $m, $s dla czasu lub $T dla czasu w formacie ggmmss.
- Wiele kolejnych zaków # dla licznika. #### da w wyniku 0001, następne przechwycenie to 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Zapisz ustawienia</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Zapisz zrzut ekranu w lokalizacji</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślna</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Współczynnik</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Jakość zapisu</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Podaj 0, aby uzyskać małe pliki skompresowane, 100 dla dużych plików nieskompresowanych.
Nie wszystkie formaty obrazów obsługują pełny zakres, JPEG obsługuje pełny zakres.</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Kopiuj dane wyjściowe skryptu do schowka</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Skrypt:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Ścieżka do skryptu, który zostanie wywołany w celu przesłania. Podczas przesyłania skrypt zostanie wywołany
ze ścieżką do tymczasowego pliku png jako pojedynczym argumentem.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Przesyłanie skryptów</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Wybierz skrypt do przesłania</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Zatrzymaj się przy zapisie skryptu na StdErr</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Oznacza przesyłanie jako zakończone niepowodzeniem, gdy skrypt zapisuje do StdErr.
Bez tego ustawienia błędy w skrypcie pozostaną niezauważone.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>Wyrażenie RegEx. Kopiuj do schowka tylko to, co pasuje do wyrażenia RegEx.
W przypadku pominięcia wszystko jest kopiowane.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Przechwyć obraz</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Prześlij do Imgur</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Komentator</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Skróty klawiszowe</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Przesyłanie</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Przesyłanie skryptów</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Zapisywanie</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Naklejki</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Obszar wycinania</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Ikona w zasobniku</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Znak wodny</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Działania</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Program do przesyłania FTP</translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Ponownie wybierz rozmiar wybranego prostokąta za pomocą uchwytów lub przesuń go, przeciągając zaznaczenie.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Użyj klawiszy strzałek, aby przesunąć zaznaczenie.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Użyj klawiszy strzałek, naciskając klawisz CTRL, aby przesunąć lewy górny uchwyt.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Użyj klawiszy strzałek, jednocześnie naciskając ALT, aby przesunąć prawy dolny uchwyt.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation>Potwierdź wybór naciskając ENTER/RETURN lub przerwij naciskając ESC.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Ten komunikat można wyłączyć w ustawieniach.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Kliknij i przeciągnij, aby wybrać prostokątny obszar, lub naciśnij klawisz ESC, aby zakończyć pracę.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Przytrzymaj wciśnięty klawisz CTRL, aby zmienić rozmiar zaznaczenia po wybraniu.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Przytrzymaj wciśnięty klawisz CTRL, aby zapobiec zmianie rozmiaru po wybraniu.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>Operacja zostanie anulowana po 60 sekundach, gdy żaden wybór nie zostanie dokonany.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Ten komunikat można wyłączyć w ustawieniach.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Zablokuj obraz podczas wycinania</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Po włączeniu tej opcji zamraża tło, podczas
wybierania prostokątnego obszaru. Zmienia również
zachowanie opóźnionych zrzutów ekranu, z tym że
przy opcji włączonej opóźnienie następuje przed
wyświetleniem obszaru wycinania, a z opcją wyłączoną
opóźnienie następuje po wyświetleniu obszaru wycinania.
Ta funkcja jest zawsze wyłączona dla Wayland i zawsze
włączone dla MacOs.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Pokaż lupę w obszarze wycinania</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Wyświetla lupę, która pozwala
powiększyć obraz tła. Ta opcja działa tylko
z włączoną funkcją &quot;Zamrażaj obraz podczas przycinania&quot;.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Pokaż linijki obszaru wycinania</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Linie poziome i pionowe przechodzące od
krawędzi pulpitu do kursora w obszarze wycinania.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Pokaż położenie i rozmiar obszaru wycinania</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Gdy lewy przycisk myszy nie jest wciśnięty pozycja 
jest wyświetlana, po naciśnięciu przycisku myszy 
wielkość wybranego obszaru jest wyświetlana po lewej stronie 
i powyżej przechwyconego obszaru.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Domyślnie zezwalaj na zmianę rozmiaru zaznaczenia obszaru prostokątnego</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Po włączeniu tej opcji, po zaznaczeniu prostokątnego
obszaru, pozwoli na zmianę rozmiaru zaznaczenia. Po
zakończeniu zmiany rozmiaru można potwierdzić wybór
naciskając wstecz.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Pokaż tekst informacyjny o obszarze wycinania</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Kolor kursora obszaru wycinania</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Ustawia kolor kursora obszaru wycinania.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Grubość kursora obszaru wycinania</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Ustawia grubość kursora obszaru wycinania.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Obszar wycinania</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Ozdobny kolor obszaru przechwytywania</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Ustawia kolor wszystkich elementów ozdobnych
w obszarze wycinania.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Przezroczystość obszaru wycinania</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Przezroczystość nie wybranego regionu w obszarze wycinania.
Im mniejsza liczba, tym obszar bardziej przezroczysty.</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>W górę</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>W dół</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Użyj domyślnych naklejek</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Ustawienia naklejek</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Pliki obrazu wektorowego (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Dodaj naklejkę</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Pokaż edytor</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Użyj ikony z zasobnika</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Po włączeniu doda ikonę do zasobnika paska zadań, jeśli obsługuje go Menedżer okien systemu operacyjnego.
Zmiana wymaga ponownego uruchomienia.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Minimalizuj do zasobnika</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Uruchom zminimalizowany do zasobnika</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Zamknij do zasobnika</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Pokaż Edytor</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Zrzut z ekranu</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Domyślna akcja ikony zasobnika</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Domyślna Akcja, która jest uruchamiana przez kliknięcie lewym przyciskiem myszy ikony zasobnika.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Ustawienia ikony zasobnika</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Skorzystaj z usługi powiadomień specyficznej dla platformy</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Gdy włączone, będzie próbował używać powiadomień specyficznych dla platformy
jeśli taka istnieje. Zmiana wymaga ponownego uruchomienia, aby zaczęła obowiązywać.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>Wyświetl ikony powiadomień w zasobniku</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Wybierz obraz</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Pliki obrazów</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Wymagany skrypt do przesłania</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Aby przesłać skrypt należy wybrać Opcje &gt; Ustawienia &gt; Przesyłanie skryptów</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Prześlij zrzut</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Masz zamiar przesłać obraz do zewnętrznego miejsca docelowego, chcesz kontynuować?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Poproś o potwierdzenie przed przesłaniem</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Typ przesyłania:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Skrypt</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Przesyłanie</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Kompilacja</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Z użyciem:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Obraz znaku wodnego</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizuj</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Obróć znak wodny</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Po włączeniu tej funkcji znak wodny zostanie dodany z obróceniem o 45 °</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Ustawienia znaku wodnego</translation>
    </message>
</context>
</TS>
